from ...data.struct import AssetWeight

class Helper:

    def init(self):
        pass

    def setup(self, saa: AssetWeight=None):
        pass
